---
title: <span class="badge object-type-scalar"></span> KiloVoltAmpereReactive
---
# <span class="badge object-type-scalar"></span> KiloVoltAmpereReactive

Energy: Kilovolt-Ampere reactive (kVAr)

## Definition

```python
# Energy: Kilovolt-Ampere reactive (kVAr)
KiloVoltAmpereReactive: typing.Literal["kvoltampreact"] = "kvoltampreact"
```
